==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/common/crafting/RunicAltarRecipe.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.crafting;

import com.google.common.base.Preconditions;
import com.google.gson.JsonArray;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import org.jetbrains.annotations.NotNull;

import vazkii.botania.common.block.BotaniaBlocks;
import vazkii.botania.common.crafting.recipe.RecipeUtils;

import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_1263;
import net.minecraft.class_1799;
import net.minecraft.class_1856;
import net.minecraft.class_1865;
import net.minecraft.class_1869;
import net.minecraft.class_1937;
import net.minecraft.class_2371;
import net.minecraft.class_2540;
import net.minecraft.class_2960;
import net.minecraft.class_3518;

public class RunicAltarRecipe implements vazkii.botania.api.recipe.RunicAltarRecipe {
	private final class_2960 id;
	private final class_1799 output;
	private final class_2371<class_1856> inputs;
	private final int mana;

	public RunicAltarRecipe(class_2960 id, class_1799 output, int mana, class_1856... inputs) {
		Preconditions.checkArgument(inputs.length <= 16, "Cannot have more than 16 ingredients");
		this.id = id;
		this.output = output;
		this.inputs = class_2371.method_10212(class_1856.field_9017, inputs);
		this.mana = mana;
	}

	@Override
	public boolean method_8115(class_1263 inv, @NotNull class_1937 world) {
		return RecipeUtils.matches(inputs, inv, null);
	}

	@NotNull
	@Override
	public final class_1799 method_8110() {
		return output;
	}

	@NotNull
	@Override
	public class_1799 method_8116(@NotNull class_1263 inv) {
		return method_8110().method_7972();
	}

	@NotNull
	@Override
	public class_2371<class_1856> method_8117() {
		return inputs;
	}

	@NotNull
	@Override
	public class_1799 method_17447() {
		return new class_1799(BotaniaBlocks.runeAltar);
	}

	@NotNull
	@Override
	public class_2960 method_8114() {
		return id;
	}

	@NotNull
	@Override
	public class_1865<?> method_8119() {
		return BotaniaRecipeTypes.RUNE_SERIALIZER;
	}

	@Override
	public int getManaUsage() {
		return mana;
	}

	public static class Serializer extends RecipeSerializerBase<RunicAltarRecipe> {
		@NotNull
		@Override
		public RunicAltarRecipe method_8121(@NotNull class_2960 id, @NotNull JsonObject json) {
			class_1799 output = class_1869.method_35228(class_3518.method_15296(json, "output"));
			int mana = class_3518.method_15260(json, "mana");
			JsonArray ingrs = class_3518.method_15261(json, "ingredients");
			List<class_1856> inputs = new ArrayList<>();
			for (JsonElement e : ingrs) {
				inputs.add(class_1856.method_8102(e));
			}
			return new RunicAltarRecipe(id, output, mana, inputs.toArray(new class_1856[0]));
		}

		@Override
		public RunicAltarRecipe method_8122(@NotNull class_2960 id, @NotNull class_2540 buf) {
			class_1856[] inputs = new class_1856[buf.method_10816()];
			for (int i = 0; i < inputs.length; i++) {
				inputs[i] = class_1856.method_8086(buf);
			}
			class_1799 output = buf.method_10819();
			int mana = buf.method_10816();
			return new RunicAltarRecipe(id, output, mana, inputs);
		}

		@Override
		public void toNetwork(@NotNull class_2540 buf, @NotNull RunicAltarRecipe recipe) {
			buf.method_10804(recipe.method_8117().size());
			for (class_1856 input : recipe.method_8117()) {
				input.method_8088(buf);
			}
			buf.method_10793(recipe.method_8110());
			buf.method_10804(recipe.getManaUsage());
		}
	}

}

==> Botania-1.20.1-451-FABRIC-20251019.133948-19-sources.jar: vazkii/botania/common/crafting/RunicAltarRecipe.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.crafting;

import com.google.common.base.Preconditions;
import com.google.gson.JsonArray;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import org.jetbrains.annotations.NotNull;

import vazkii.botania.common.block.BotaniaBlocks;
import vazkii.botania.common.crafting.recipe.RecipeUtils;

import java.util.ArrayList;
import java.util.List;
import net.minecraft.class_1263;
import net.minecraft.class_1799;
import net.minecraft.class_1856;
import net.minecraft.class_1865;
import net.minecraft.class_1869;
import net.minecraft.class_1937;
import net.minecraft.class_2371;
import net.minecraft.class_2540;
import net.minecraft.class_2960;
import net.minecraft.class_3518;
import net.minecraft.class_5455;

public class RunicAltarRecipe implements vazkii.botania.api.recipe.RunicAltarRecipe {
	private final class_2960 id;
	private final class_1799 output;
	private final class_2371<class_1856> inputs;
	private final int mana;

	public RunicAltarRecipe(class_2960 id, class_1799 output, int mana, class_1856... inputs) {
		Preconditions.checkArgument(inputs.length <= 16, "Cannot have more than 16 ingredients");
		this.id = id;
		this.output = output;
		this.inputs = class_2371.method_10212(class_1856.field_9017, inputs);
		this.mana = mana;
	}

	@Override
	public boolean method_8115(class_1263 inv, @NotNull class_1937 world) {
		return RecipeUtils.matches(inputs, inv, null);
	}

	@NotNull
	@Override
	public final class_1799 method_8110(@NotNull class_5455 registries) {
		return output;
	}

	@NotNull
	@Override
	public class_1799 method_8116(@NotNull class_1263 inv, @NotNull class_5455 registries) {
		return method_8110(registries).method_7972();
	}

	@NotNull
	@Override
	public class_2371<class_1856> method_8117() {
		return inputs;
	}

	@NotNull
	@Override
	public class_1799 method_17447() {
		return new class_1799(BotaniaBlocks.runeAltar);
	}

	@NotNull
	@Override
	public class_2960 method_8114() {
		return id;
	}

	@NotNull
	@Override
	public class_1865<?> method_8119() {
		return BotaniaRecipeTypes.RUNE_SERIALIZER;
	}

	@Override
	public int getManaUsage() {
		return mana;
	}

	public static class Serializer implements class_1865<RunicAltarRecipe> {
		@NotNull
		@Override
		public RunicAltarRecipe method_8121(@NotNull class_2960 id, @NotNull JsonObject json) {
			class_1799 output = class_1869.method_35228(class_3518.method_15296(json, "output"));
			int mana = class_3518.method_15260(json, "mana");
			JsonArray ingrs = class_3518.method_15261(json, "ingredients");
			List<class_1856> inputs = new ArrayList<>();
			for (JsonElement e : ingrs) {
				inputs.add(class_1856.method_52177(e));
			}
			return new RunicAltarRecipe(id, output, mana, inputs.toArray(new class_1856[0]));
		}

		@Override
		public RunicAltarRecipe method_8122(@NotNull class_2960 id, @NotNull class_2540 buf) {
			class_1856[] inputs = new class_1856[buf.method_10816()];
			for (int i = 0; i < inputs.length; i++) {
				inputs[i] = class_1856.method_8086(buf);
			}
			class_1799 output = buf.method_10819();
			int mana = buf.method_10816();
			return new RunicAltarRecipe(id, output, mana, inputs);
		}

		@Override
		public void toNetwork(@NotNull class_2540 buf, @NotNull RunicAltarRecipe recipe) {
			buf.method_10804(recipe.method_8117().size());
			for (class_1856 input : recipe.method_8117()) {
				input.method_8088(buf);
			}
			buf.method_10793(recipe.output);
			buf.method_10804(recipe.getManaUsage());
		}
	}

}
